function Kaibelpressure ()
%Project: Steady-state Model of Pressure Drop in Kaibel Column
%Simplification v.1.0
%Date: 20.07.2018
%Creator: Johana Korbelarova

%Assumptions: No Liquid interference, appprox. constants,
%Outcome: Pressure drop as a fcn of vapor flow, later of valve position,
%use fsolve
%
% Input global data
global Mr Dens Tb V_m RL RV
Mr.butanol = 0.07412; %molar weight of butanol [kg/mol]
Mr.propanol = 0.0601; %molar weight of propanol [kg/mol]
Mr.ethanol = 0.04607; %molar weight of ethanol [kg/mol]
Mr.methanol = 0.03204; %molar weight of methanol [kg/mol]

Dens.butanol = 0.81; % density of butanol [kg/l]
Dens.propanol = 0.81; % density of propanol [kg/l]
Dens.ethanol = 0.789; % density of ethanol [kg/l]
Dens.methanol = 0.7918; % density of methanol [kg/l]

Tb.butanol = 390.85; % boiling point of butanol [K]
Tb.propanol = 370.5; % boiling point of propanol [K]
Tb.ethanol = 351.5; % boiling point of ethanol [K]
Tb.methanol = 337.9; % boiling point of methanol [K]

%
%Estimation of the molar vapor  flow from reboiler (simple)

T=390.15; % Temperature in the reboiler, [K] 
y=[1; 0; 0; 0]; % Composition in reboiler, simplif. butanol only
deltavap_h=vaporenthalpy(T,y); % evaporation enthalpy;...
                             % fcn of T and composition; [J/mol]
                             % FOR NOW: butanol enthalpy only
Q_set = 1.8; % energy input setpoint for reboiler duty, range 0-3

Q=reboilerduty(Q_set); % actual energy input from electric heater; [W]
V_m=reboiler(Q,deltavap_h); % molar vapor flow from reboiler; [mol/s]


%% Molar vapor flow to mass and volumetric flows

% Mass flow from the reboiler
V_1_w = V_m * Mr.butanol;  % mass vapor flow from reboiler; [kg/s]

% Volumetric flow from the reboiler XX vapor density
%V_1_v = V_1_m / (Dens.butanol*10^3); % volumetric vapor flow from reboiler; [m^3/s]
%% Vapor split

RV=0.5;



%% Pressure model

% set of equations to solve
fun = @pressuremodel; 
% initial values
V_P_0 = V_m/2; 
V_M_0 = V_m/2;
delta_p_P_0 = 1500;
delta_p_M_0 = 1500;
delta_p_T_0 =2000; %[Pa]
x_0 = [V_P_0; V_M_0; delta_p_P_0; delta_p_M_0; delta_p_T_0];
%options
opt = optimoptions('fsolve','Display', 'iter');%,'Algorithm',...
   % 'levenberg-marquardt');
% fsolve of the model
[x,fval] = fsolve(fun, x_0, opt);
V_P = x(1)
V_M = x(2)
delta_p_P = x(3)
delta_p_M = x(4)
delta_p_T = x(5)




end