function cf_av = drag_coeff ()
%Computing of drag coefficient - for whole column
global Mr Tb 
h(1)= 1.10; % [m], packing height section 1 
h(2)= 1.60; % [m], packing height section 2 
h(3)= 0.65; % [m], packing height section 3 
h(4)= 0.65; % [m], packing height section 4 
h(5)= 0.75; % [m], packing height section 5 
h(6)= 0.90; % [m], packing height section 6 
h(7)= 0.65; % [m], packing height section 7 
delta_h = h(1) + h(2) + h(3) + h(6); % packing height, sum for whole column

%Composition average - whole column (But - prop - eth - met) from Hysys
y = [2.57E-01;
3.50E-01;	    
2.93E-01;	
1.00E-01];	

% %Inner diameter [m]
% d=ones(7,1)*0.05; % diameter in sections 1,2,4,5,6,7
% d(6) = 0.07; % diameter in section 6
% %Inner area [m^2]
% A= pi.* (d./2).^2; %inner area [m^2]

A_av = 0.04;%average inner area for whole column [m^2]

%Hydraulic diameter of gas flow channel
a_p = 750; % [m^2/m^3] specific geometric area for the packing
         % 6mm glass Raschig rings, estimation
d_hg = 4 / a_p;



%Ideal gas constant
R = 8.314; %[J/(mol K)]

%Compressibility factor
z=1; % Ideal gas law

% Pressure
p = 101300; % [Pa] atmospheric pressure

Mr_mix = Mr.butanol * y (1) + Mr.propanol * (2) + ...
    Mr.ethanol * y(3) + Mr.methanol * y(4); 
Tb_mix = Tb.butanol * y (1) + Tb.propanol * (2) + ...
              Tb.ethanol * y(3) + Tb.methanol * y(4); 
          
          
%Pressure measurement
delta_x =  [7; 22; 128; 251]; %[mm] reboiler pressure
g = 9.81; %[m.s^-2] gravitational force
Dens.ethanol = 0.789; % density of ethanol [kg/l]
delta_p= delta_x .* 10^-3 * Dens.ethanol .* 10^3 *g; %[Pa] at the reboiler - whole column

Q_set =  [1.2; 1.4; 1.8; 2]; % reboiler setpoint
Q=reboilerduty(Q_set); % actual energy input from electric heater; [W]

T=390.15; % Temperature in the reboiler, [K] 

deltavap_h=vaporenthalpy(T,y); % evaporation enthalpy;...
                             % fcn of T and composition; [J/mol]
                             
                             
V=reboiler(Q,deltavap_h); % molar vapor flow from reboiler; [mol/s]



cf = delta_p ./ delta_h .* d_hg .* ((2.* A_av.^2)./V.^2).* p ./...
    (Mr_mix.*z.*T.*Tb_mix);
plot(cf,Q_set, '*')

cf_av = (cf(3)+cf(4))/2; % average of top two Q values

end