 function F=pressuremodel(x)
% Vapor flow - pressure model for Kaibel column
%Date: 20.07.2018
%Creator: Johana Korbelarova

% Not in the model: Change of the vapor flow from reboiler to Y split
% section
F= zeros(5,1);
global V_m Mr Tb RV RL
%%
%Constants:

R=zeros(7,1);
% k_P = 8; %prefr. constant: sections 1,2
% k_M = 10; % main c. constant: sections 4,5,7
% k_B = 2; %reboiler constant: section 6
% k_T = 1; % condenser constant: section 3

%Packing height z in column sections (numbering according to Kvernland)
h=zeros(7,1);
h(1)= 1.10; % [m], packing height section 1 
h(2)= 1.60; % [m], packing height section 2 
h(3)= 0.65; % [m], packing height section 3 
h(4)= 0.65; % [m], packing height section 4 
h(5)= 0.75; % [m], packing height section 5 
h(6)= 0.90; % [m], packing height section 6 
h(7)= 0.65; % [m], packing height section 7 

global h A

%Inner diameter [m]
d=ones(7,1)*0.05; % diameter in sections 1,2,4,5,6,7
d(6) = 0.07; % diameter in section 6
%Inner area [m^2]
A= pi.* (d./2).^2; %inner area [m^2]

% Drag coefficient 
 cf_av =1.6498;  %  estimated by experiments, from fcn cf_av = drag_coeff ()
%Hydraulic diameter of gas flow channel
a_p = 750; % [m^2/m^3] specific geometric area for the packing
         % 6mm glass Raschig rings
d_hg = 4 / a_p;

%Composition to determine Tb.mix, Mr.mix, z - steady state - from simulation Ivar
%average for each section
y.methanol =[0.158342374;	
             0.017381605;	
             0.408494;
             0.130993664;	
             1.21E-05;	
             6.69E-09;	
             9.61E-03];	
y.ethanol =[0.254066329;	
            0.035192743;		
            0.578165914;		
            0.68511214;		
            1.05E-02;		
            3.65E-07;		
            6.07E-01];

y.propanol =[0.55530929;	
             0.634574137;
             1.33E-02;
             0.183882317;
             4.03E-01;
             3.09E-02;
             3.78E-01];


y.butanol = [3.23E-02;
             0.312851515;
             3.19E-07;
             1.19E-05;
             5.86E-01;
             9.69E-01;
             5.26E-03];
y.all= [y.butanol y.propanol y.ethanol y.methanol];

%HETP = 0.16; % [m] height equivalent of a theoretical plate (Deepanthshu)


%Ideal gas constant
R_id = 8.314; %[J/(mol K)]

%Compressibility factor
z=1; % Ideal gas law

% Pressure
p = 101300; % [Pa] atmospheric pressure

for i=1:7
    Mr.mix(i) = Mr.butanol * y.all (i,1) + Mr.propanol * y.all(i,2) + ...
              Mr.ethanol * y.all(i,3) + Mr.methanol * y.all(i,4); 
    Tb.mix (i) = Tb.butanol * y.all (i,1) + Tb.propanol * y.all(i,2) + ...
              Tb.ethanol * y.all(i,3) + Tb.methanol * y.all(i,4); 
          
    const(i)= (cf_av/(d_hg *2* A(i)^2)) *( Mr.mix(i) * z * R_id *...
        Tb.mix(i) / p);
   
    R(i) = const(i)*h(i);
end

% Vapor split valves
%valve position given by RV, z is actual valve position - 8 steps,
%split range control
if RV == 0.5
    z_P=8;
    z_M=8;
elseif RV>0.5
    z_P=8;
    z_M=16*(1-RV)
else     
    z_P=16*RV
    z_M=8;
end
%valve resistance
k_P = 1000;
k_M = 1000;

R_PV = k_P*(8-z_P);
R_MV = k_M*(8-z_M);

% Liquid influence

% Liquid split


%Assigned resistance constants
R_P0 = R(1) + R(2); %constant resistance in prefractionator due to packing
R_P = R_P0 + R_PV; % resistance in prefractionator

R_M0 = R(4) + R(5) + R(7);%constant resistance in main col. due to packing
R_M = R_M0+ R_MV; %resistance in main column

R_B = R(7); %resistance in bottom section
R_C = R(1); % resistance in top section

R_T = R_B +(R_P*R_M)/(R_P+R_M) + R_C; % total resistance in  the column

%Model equations

F(1) = x(5) - R_T * V_m^2; % total pressure drop
F(2) = V_m - x(1) - x(2); % vapor flow split

F(3) = x(3) - R_P * x(1)^2; % delta pressure in the prefractionator
F(4) = x(4) - R_M * x(2)^2; % delta pressure in the main column

F(5) = x(3) - x(4); % 0 difference in pressure between branches

% %Linear
% %Model equations
% 
% F(1) = x(5) - R_T * V_1; % pressure through first packing above reboiler
% F(2) = V_1 - x(1) - x(2); % vapor flow split
% 
% F(3) = x(3) - R_P * x(1); % delta pressure in the prefractionator
% F(4) = x(4) - R_M * x(2); % delta pressure in the main column
% 
% F(5) = x(3) - x(4); % 0 difference in pressure between branches

end