function V_m=reboiler(Q,deltavap_h)
% Calculates the vapor flow (boil up) from reboiler, through energy balance
%From E.b. for Evaporator (Sigurd Chemeng book)
%Date: 13.3.2018
%Creator: Johana Korbelarova


%Variables
% L_in;          % liquid flow entering reboiler [mol/s]
% V_out          % vapor flow leaving the reboiler [mol/s]
% T=100          % temperature in reboiler [K]
%deltavap_h      % evaporation enthalpy; T, composition fcn; [J/mol]
%Q               % energy input from electric heater, [W]

%Mass Balance
%dmdt=L_in - V_out

%Energy Balance
%m*cp_L(T) * dTdt = L_in * cp_L(T) * (T - T_in) - V_out *
%deltavap_h(T) + Q

% Assumptions: pressure-volume changes neglected, shaft work neglected,
% dmdt=0 mass steady state, T_in=T, dT/dt=0 -the time range is big enough,
% cp_L constant with temperature

%Vapor flow:
V_out=Q/deltavap_h;

V_m=V_out;
end




