function deltavap_h=vaporenthalpy(T,y)
global Mr
%Calculation of evaporation enthalpy for given temperature and composition
%Date: 13.3.2018
%Creator: Johana Korbelarova


% T is input temperature [K]
% y is molar fraction of mixture composition [-]: y=[but; prop; eth; meth]

%%
% 1 - butanol
% valid for temperatures: 25 - 137 C 
if (298.15 < T) && (T < 410.15)
    %heat of vaporization of butanol at given temperature [J/mol],T in [K]
    deltavap_h_butanol = 1e3*62.53*(1-(T/562.9))^(0.6960)*exp(-(-0.6584)...
   *(T/562.9)); 
else
    deltavap_h_butanol = 0;
    fprintf('Temperature input is not valid for butanol eq. \n');
end
%heat of vaporization of butanol at given temperature, mass [kg/mol]
deltavap_h_butanol_m = deltavap_h_butanol / Mr.butanol;
%%
% 1 - propanol
% valid for temperatures: 25 - 117 C 
if (298.15 < T) && (T < 390.15)
    %heat of vaporization of propanol at given temperature [J/mol],T in [K]
    deltavap_h_propanol = 1e3*52.06*(1-(T/536.7))^(0.6808)*exp(-(-0.8386)...
        *(T/536.7));
else
    deltavap_h_propanol = 0;
    fprintf('Temperature input is not valid for propanol eq. \n');
end
%heat of vaporization of propanol at given temperature, mass [kg/mol]
deltavap_h_propanol_m = deltavap_h_propanol / Mr.propanol;
%%
% ethanol
% valid for temperatures: 25 - 196 C 
if (298.15 < T) && (T < 469.15)
    %heat of vaporization of ethanol at given temperature [J/mol],T in [K]
    deltavap_h_ethanol = 1e3*50.43*(1-(T/513.9))^(0.4989)*exp(-(-0.4475)...
        *(T/513.9));
else
    deltavap_h_ethanol = 0;
    fprintf('Temperature input is not valid for ethanol eq. \n');
end
%heat of vaporization of ethanol at given temperature, mass [kg/mol]
deltavap_h_ethanol_m = deltavap_h_ethanol / Mr.ethanol;
%%
% methanol
% valid for temperatures: 0 - 230 C 
if (273.15 < T) && (T < 503.15)
    %heat of vaporization of methanol at given temperature [J/mol],T in [K]
    deltavap_h_methanol = 1e3*46.4052*(1-(T/512.6))^(0.43207)...
        *exp(-(-0.30235)*(T/512.6));
else
    deltavap_h_methanol = 0;
    fprintf('Temperature input is not valid for methanol eq. \n');
end
%heat of vaporization of methanol at given temperature, mass [kg/mol]
deltavap_h_methanol_m = deltavap_h_methanol / Mr.methanol;
%%
%calculation of the enthalpy of the mixture (Add the mol. fractions etc.)


deltavap_h = y(1)* deltavap_h_butanol + y(2) * deltavap_h_propanol + ...
    + y(3) * deltavap_h_ethanol + y(4) * deltavap_h_methanol;
end